# tmj
Small CLI utility script to help me with TMJ disorder isometric jaw exercises.

The exercises used are as in [this video](https://www.youtube.com/watch?v=Vrz25x3qnTY&feature=youtu.be&t=208).

In the program they are labelled as 'push up', 'pull down', 'push left', and 'push right'.

## Prerequisites
- Python 3.7

## Installation
```bash
pip install tmj
```

## Usage
```bash
$ tmj
```